==> fitment-service-1.0.2-20190222.083908-2-sources.jar: com/bizvane/fitmentservice/models/po/AppletVipCartPO.java <==
package com.bizvane.fitmentservice.models.po;

import java.util.Date;

public class AppletVipCartPO {
    /**
     * 卡面字段1
     */
    private String cardField1;
    /**
     * 卡面字段2
     */
    private String cardField2;

    private Long appletVipCardId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long gradeId;

    private String cardStyle;

    private Boolean isImg;

    private String upgradeInfo;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Boolean valid;

    public String getCardField1() {
        return cardField1;
    }

    public void setCardField1(String cardField1) {
        this.cardField1 = cardField1;
    }

    public String getCardField2() {
        return cardField2;
    }

    public void setCardField2(String cardField2) {
        this.cardField2 = cardField2;
    }

    public Long getAppletVipCardId() {
        return appletVipCardId;
    }

    public void setAppletVipCardId(Long appletVipCardId) {
        this.appletVipCardId = appletVipCardId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getGradeId() {
        return gradeId;
    }

    public void setGradeId(Long gradeId) {
        this.gradeId = gradeId;
    }

    public String getCardStyle() {
        return cardStyle;
    }

    public void setCardStyle(String cardStyle) {
        this.cardStyle = cardStyle == null ? null : cardStyle.trim();
    }

    public Boolean getIsImg() {
        return isImg;
    }

    public void setIsImg(Boolean isImg) {
        this.isImg = isImg;
    }

    public String getUpgradeInfo() {
        return upgradeInfo;
    }

    public void setUpgradeInfo(String upgradeInfo) {
        this.upgradeInfo = upgradeInfo == null ? null : upgradeInfo.trim();
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }
}

==> fitment-service-1.0.2-20190425.051956-8-sources.jar: com/bizvane/fitmentservice/models/po/AppletVipCartPO.java <==
package com.bizvane.fitmentservice.models.po;

import com.bizvane.members.facade.models.ExtendPropertyModel;
import com.bizvane.members.facade.models.bo.ExtendPropertyVipCardStyleBo;
import com.bizvane.members.facade.vo.ExtendPropertyVO;
import com.bizvane.members.facade.vo.ExtendPropertyVipCardVo;

import java.util.Date;
import java.util.List;

public class AppletVipCartPO {
    private Long appletVipCardId;

    private Long sysCompanyId;

    private Long sysBrandId;

    private Long gradeId;

    private String cardStyle;

    private Boolean isImg;

    private String upgradeInfo;

    private Long createUserId;

    private String createUserName;

    private Date createDate;

    private Long modifiedUserId;

    private String modifiedUserName;

    private Date modifiedDate;

    private Boolean valid;
    private List<ExtendPropertyVipCardVo> extendPropertyVipCard;

    private List<ExtendPropertyVipCardStyleBo> extendPropertyVOs;

    public List<ExtendPropertyVipCardStyleBo> getExtendPropertyVOs() {
        return extendPropertyVOs;
    }

    public void setExtendPropertyVOs(List<ExtendPropertyVipCardStyleBo> extendPropertyVOs) {
        this.extendPropertyVOs = extendPropertyVOs;
    }

    public Long getAppletVipCardId() {
        return appletVipCardId;
    }

    public void setAppletVipCardId(Long appletVipCardId) {
        this.appletVipCardId = appletVipCardId;
    }

    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public Long getGradeId() {
        return gradeId;
    }

    public void setGradeId(Long gradeId) {
        this.gradeId = gradeId;
    }

    public String getCardStyle() {
        return cardStyle;
    }

    public void setCardStyle(String cardStyle) {
        this.cardStyle = cardStyle == null ? null : cardStyle.trim();
    }

    public Boolean getIsImg() {
        return isImg;
    }

    public void setIsImg(Boolean isImg) {
        this.isImg = isImg;
    }

    public String getUpgradeInfo() {
        return upgradeInfo;
    }

    public void setUpgradeInfo(String upgradeInfo) {
        this.upgradeInfo = upgradeInfo == null ? null : upgradeInfo.trim();
    }

    public Long getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    public String getModifiedUserName() {
        return modifiedUserName;
    }

    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    public Date getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public Boolean getValid() {
        return valid;
    }

    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    public List<ExtendPropertyVipCardVo> getExtendPropertyVipCard() {
        return extendPropertyVipCard;
    }

    public void setExtendPropertyVipCard(List<ExtendPropertyVipCardVo> extendPropertyVipCard) {
        this.extendPropertyVipCard = extendPropertyVipCard;
    }
}
